/*
 * Copyright (c) 2000,2006,2012 CNRS/LAAS
 *
 * Permission to use, copy, modify, and/or distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
#ifndef _KVH1000_H
#define _KVH1000_H

/**
 ** Anthony Mallet - Tue Aug  1 2000
 **
 ** Functions to open, read and decode gyro data on a serial line :
 **
 **      int gyroOpen(char *device)
 **      int gyroRead(int fd, char *buf)
 **      int gyroDecode(GyroData *gyro)
 **
 **/

#define VERBOSE 0

#define GYRO_KVH1000_SERIAL_SPEED		9600

#define GYRO_KVH1000_TEMP_RESOLUTION		(0.05)
#define GYRO_KVH1000_RATE_RESOLUTION		(0.00305 * M_PI / 180.0)

/* Useless to be more precise than earth revolution = 360/24/3600=0.0042 deg/s.
   Moreover, the gyro KVH1000 precision seems about 0.02 deg/s.
   With the threshold, derivation will be avoid.  */
#define GYRO_KVH1000_W_MIN (0.02*3.1415926/180)

#define GYRO_KVH1000_READ_TASK_NAME		"tGyro"
#define GYRO_KVH1000_READ_TASK_PRIORITY		20
#define GYRO_KVH1000_READ_TASK_STACK_SIZE	8192



/* --
   -- Structure shared by server and client
   -- */
struct GYRO_KVH1000_DATA {
	struct GYRO_DATA gd;	/* device independant part - must come first */
	int fd;			/* serial line file descriptor */
	pthread_t taskId;	/* read task id */
	int stop;		/* read task stop flag */
	int sn;		  /* serial number (SN) */
	int snBit;	  /* current SN bit */
	unsigned snI:1;	  /* true if first SN bit has been received */
	unsigned snO:1;	  /* true if all SN bits have been received */

	float temp;		/* temperature C */
	unsigned char tlsb;	/* lsb */
	unsigned char tmsb;	/* msb */

	char buf[8];		/* raw data */

};


#endif
